@@ -73,17 +73,20 @@ class CRFExtractor:
                             num_tokens_match = len(fact["str_val"].split(" "))
                             # replace initial labels with correct ones
                             for j in range(num_tokens_before_match, num_tokens_before_match+num_tokens_match):
-                                labels[i][j] = label
+                                try:
+                                    labels[i][j] = label
+                                except IndexError:
+                                    pass
                 try:
                     yield [({name:content[i][j] for name,content in layers.items()}, labels[i][j]) for j, token in enumerate(sentence)]
                 except IndexError:
-                    raise exceptions.InvalidInputError("Layer lengths do not match!")
+                    pass
         else:
             for i, sentence in enumerate(layers[FEATURE_LAYER_WORD]):
                 try:
                     yield i, [{name:content[i][j] for name,content in layers.items()} for j, token in enumerate(sentence)]
                 except IndexError:
-                    raise exceptions.InvalidInputError("Layer lengths do not match!")
+                    pass
 
 
     def train(self, mlp_documents: List[dict], mlp_field: str = "text_mlp", save_path: str = "my_crf_model"):
@@ -222,15 +225,16 @@ class CRFExtractor:
             # get spans
             tokenized_sentence = " ".join(sentences[sent_index])
             pattern = re.compile(re.escape(str_val))
-            matching_spans = [(match.start(), match.end()) for match in pattern.finditer(tokenized_sentence)]
-            fact = {
-                "fact": fact_name if not label_suffix else f"{fact_name}_{label_suffix}", # if the user has specified a suffix, append it to the fact name
-                "str_val": str_val,
-                "sent_index": sent_index,
-                "doc_path": f"{field_name}.{FEATURE_LAYER_WORD}",
-                "spans": json.dumps(matching_spans)
-            }
-            yield fact
+            for match in pattern.finditer(tokenized_sentence):
+                matching_spans = [(match.start(), match.end())]
+                fact = {
+                    "fact": fact_name if not label_suffix else f"{fact_name}_{label_suffix}", # if the user has specified a suffix, append it to the fact name
+                    "str_val": str_val,
+                    "sent_index": sent_index,
+                    "doc_path": f"{field_name}.{FEATURE_LAYER_WORD}",
+                    "spans": json.dumps(matching_spans)
+                }
+                yield fact
 
 
     def load(self, file_path: str):
